@@ -281,7 +281,12 @@ class Testbed:
         for c in self.setup_commands:
             rc = self.execute(['sh', '-ec', c], xenv=xenv, kind='install')[0]
             if rc:
-                self.bomb('testbed setup commands failed with status %i' % rc)
+                # setup scripts should exit with 100 if it's the package's
+                # fault, otherwise it's considered a transient testbed failure
+                if rc == 100:
+                    self.badpkg('testbed setup commands failed with status 100')
+                else:
+                    self.bomb('testbed setup commands failed with status %i' % rc)
 
         # if the setup commands affected the boot, then reboot
         if self.setup_commands and 'reboot' in self.caps:
@@ -467,13 +472,13 @@ class Testbed:
         This requires root privileges and a writable file system.
         '''
         # create a dummy deb with the deps
-        pkgdir = tempfile.mkdtemp(prefix='adt-satdep.')
+        pkgdir = tempfile.mkdtemp(prefix='autopkgtest-satdep.')
         debdir = os.path.join(pkgdir, 'DEBIAN')
         os.chmod(pkgdir, 0o755)
         os.mkdir(debdir)
         os.chmod(debdir, 0o755)
         with open(os.path.join(debdir, 'control'), 'w') as f:
-            f.write('''Package: adt-satdep
+            f.write('''Package: autopkgtest-satdep
 Section: oldlibs
 Priority: extra
 Maintainer: autogenerated
@@ -483,7 +488,7 @@ Depends: %s
 Description: satisfy autopkgtest test dependencies
 ''' % (self.dpkg_arch, deps))
 
-        deb = TempPath(self, 'adt-satdep.deb')
+        deb = TempPath(self, 'autopkgtest-satdep.deb')
         subprocess.check_call(['dpkg-deb', '-b', pkgdir, deb.host],
                               stdout=subprocess.PIPE)
         shutil.rmtree(pkgdir)
@@ -520,8 +525,8 @@ Description: satisfy autopkgtest test dependencies
                     self.run_shell()
             else:
                 # apt-get -f may succeed, but its solution might remove
-                # adt-satdep, which is still a failure
-                rc = self.execute(['dpkg', '--status', 'adt-satdep'],
+                # autopkgtest-satdep, which is still a failure
+                rc = self.execute(['dpkg', '--status', 'autopkgtest-satdep'],
                                   stdout=subprocess.PIPE,
                                   stderr=subprocess.PIPE)[0]
 
@@ -539,19 +544,19 @@ Description: satisfy autopkgtest test dependencies
                             'apt-get update or use -U.')
             break
 
-        # remove adt-satdep to avoid confusing tests, but avoid marking our
+        # remove autopkgtest-satdep to avoid confusing tests, but avoid marking our
         # test dependencies for auto-removal
         out = self.check_exec(['apt-get', '--simulate', '--quiet',
                                '-o', 'APT::Get::Show-User-Simulation-Note=False',
                                '--auto-remove',
-                               'purge', 'adt-satdep'],
+                               'purge', 'autopkgtest-satdep'],
                               True)
         test_deps = []
         for line in out.splitlines():
             if not line.startswith('Purg '):
                 continue
             pkg = line.split()[1]
-            if pkg != 'adt-satdep':
+            if pkg != 'autopkgtest-satdep':
                 test_deps.append(pkg)
         if test_deps:
             adtlog.debug('Marking test dependencies as manually installed: %s' %
@@ -562,7 +567,7 @@ Description: satisfy autopkgtest test dependencies
                 self.check_exec(['apt-mark', 'manual', '-qq'] + test_deps[batch:batch + 20])
                 batch += 20
 
-        self.execute(['dpkg', '--purge', 'adt-satdep'])
+        self.execute(['dpkg', '--purge', 'autopkgtest-satdep'])
 
     def install_tmp(self, deps, recommends=False):
         '''Unpack dependencies into temporary directory
