@@ -490,8 +490,9 @@ def parse_click_manifest(manifest, testbed_caps, clickdeps, use_installed,
             desc['command'] = \
                 'PYTHONPATH=app/tests/autopilot:tests/autopilot:$PYTHONPATH '\
                 'python3 -m autopilot.run run -v -f subunit -o ' \
-                '$ADT_ARTIFACTS/%s.subunit ' % name + os.environ.get(
-                    'ADT_AUTOPILOT_MODULE', desc['autopilot_module'])
+                '$AUTOPKGTEST_ARTIFACTS/%s.subunit ' % name + os.environ.get(
+                    'AUTOPKGTEST_AUTOPILOT_MODULE',
+                    os.environ.get('ADT_AUTOPILOT_MODULE', desc['autopilot_module']))
             desc.setdefault('depends', []).insert(
                 0, 'ubuntu-ui-toolkit-autopilot')
             desc['depends'].insert(0, 'autopilot-touch')
